==> haskell-wl-pprint-extras-3.5.0.5-374-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-5CwL49WfsyeD6SzeomXCZd
key:                  wl-pprint-extras-3.5.0.5-5CwL49WfsyeD6SzeomXCZd
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  8ecb2b0895ff67f0d78cd298ae229251
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-5CwL49WfsyeD6SzeomXCZd
depends:
    base-4.15.1.0 containers-0.6.4.1
    semigroupoids-5.3.7-Xhu880qc0CSSuormkKAs text-1.2.5.0
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-379-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-JLkd6W9x0UsIt9RbVrJKz6
key:                  wl-pprint-extras-3.5.0.5-JLkd6W9x0UsIt9RbVrJKz6
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  93b8906e6826d47ff1c69fd4d4ae20ee
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wl-pprint-extras
hs-libraries:         HSwl-pprint-extras-3.5.0.5-JLkd6W9x0UsIt9RbVrJKz6
depends:
    base-4.15.1.0 containers-0.6.4.1
    semigroupoids-5.3.7-FJaLrMwwj8OGSLe5yqiT1J text-1.2.5.0
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
